@@ -138,13 +138,14 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
         keyw = keywords,
         prp = prp
     )
-    print(params)
+
     r = requests.get(searchUrl, params=params)
     resDict = r.json()
+
     if len(resDict['errors']) > 0:
         e = " *** ".join(resDict['errors'])
         raise queryError(e)
-    return result(resDict), prop2key
+    return result(resDict)
 
 
 class result(object):
