@@ -8,7 +8,7 @@ Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.p
 """
 
 from __future__ import print_function
-from . import (prop2abr, abr2prop, query, prop2key, __version__)
+from . import (prop2abr, abr2prop, query, __version__)
 import argparse
 import datetime
 import sys
@@ -257,9 +257,6 @@ def cliQuery(comp='', numOfComp=0, year='', author='', keywords='', prop='', ver
         print('Make query to NIST... ', end='')
         spinner.start()
     try:
-        #JOAO
-        print("entrou")
-        #JOAO
         resObj = query(comp=comp,
                               numOfComp=numOfComp,
                               year=year,
@@ -267,20 +264,12 @@ def cliQuery(comp='', numOfComp=0, year='', author='', keywords='', prop='', ver
                               keywords=keywords,
                               prop=prop)
     except:
-        #JOAO
-        print("excepto")
-        #JOAO
         if verbose:
             spinner.stop()
         e = sys.exc_info()[1]
         print('Error: {0:s}'.format(str(e)))
-        #JOAO
-        #exit(1)
-        #JOAO
+        exit(1)
     else:
-        #JOAO
-        print("balela")
-        #JOAO
         if verbose:
             spinner.stop()
             print('\b done! ({0:d} hits)'.format(len(resObj)))
